/*
*   DeltaVerifier -- Verifies that pressure ratio inputs are reasonable.
*   
*   Copyright (C) 1999 - 2012 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import java.awt.Component;
import javax.measure.quantity.Dimensionless;
import javax.measure.quantity.Length;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.ParamVerifier;


/**
*  Verifies that the pressure ratio the user entered
*  is greater than the minimum possible.
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 9, 1998
*  @version  February 18, 2012
**/
public class DeltaVerifier implements ParamVerifier, AtmosSharedData {
	
	private final Parameter<Dimensionless> limit;
	
	public DeltaVerifier() {
		//	Ask the model what the minimum value is.
		Parameter<Length> oldAlt = atmosModel.getAltitude();
		atmosModel.setAltitude(atmosModel.maxAltitude());
		limit = atmosModel.getPressureRatio();
		atmosModel.setAltitude(oldAlt);
	}
	
	/**
	*  Check to see if the input value is valid for this parameter.
	*
	*  @param   root   The root component containing the parameter input text field
	*                  for the parameter being verified.
	*  @param   value  The value of the parameter as input by the user.
	*  @return  If "value" is valid, it should be output.  If "value" is invalid or
	*           out of range, a valid value is output or Float.NaN if nothing else.
	*           If ParamInput (which calls this routine) recieves a value of Float.NaN,
	*           it will clear the parameter.
	**/
	public Parameter check(Component root, Parameter value) {
		if (value.isLessThan(limit))
			return limit;
		
		return value;
	}

}
