/*
*   VEfn_VT_sigma -- Calculates equivelent airspeed as a function of VT & sigma.
*   
*   Copyright (C) 1999 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Velocity;
import javax.measure.quantity.Dimensionless;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates equivalent airspeed based on true airspeed and
*  the density ratio with altitude.
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 18, 1998
*  @version  July 24, 2011
**/
public class VEfn_VT_sigma extends AbstractParamMethod<Velocity> {
	
	/**
	*  Constructor for this method.
	*
	*  @param   VT		Label for the "true airspeed" parameter.
	*  @param   sigma	Label for the "density ratio" parameter.
	**/
	public VEfn_VT_sigma(String VT, String sigma) {
		_inputLabels = new String[2];
		_inputLabels[0] = VT;
		_inputLabels[1] = sigma;
	}
	
	
	/**
	*  Calculates equivalent airspeed based on true airspeed and
	*  the density ratio with altitude.
	*  Method:  VE = VT*sqrt(sigma)
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=true airspeed (VT), 1=density ratio with altitude (sigma)].
	*  @return  Equivalent airspeed (VE) in m/s.
	**/
	public Parameter<Velocity> calc(Parameter[] inputs) {
		Parameter<Velocity> VT = inputs[0];
		Parameter<Dimensionless> sigma = inputs[1];
		
		Parameter VE = VT.times(sigma.sqrt());
		
		return VE;
	}

}
