/*
*   afn_VT_M -- Calculates speed of sound as a function of M and VT.
*   
*   Copyright (C) 1999 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Dimensionless;
import javax.measure.quantity.Velocity;
import javax.measure.unit.SI;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates the speed of sound based on true airspeed
*  and Mach number.
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  October 18, 1998
*  @version  July 20, 2011
**/
public class afn_VT_M extends AbstractParamMethod<Velocity> {
	
	/**
	*  Constructor for this method.
	*
	*  @param   VT	Label for the "true airspeed" parameter.
	*  @param   M	Label for the "Mach number" parameter.
	**/
	public afn_VT_M(String VT, String M) {
		_inputLabels = new String[2];
		_inputLabels[0] = VT;
		_inputLabels[1] = M;
	}
	
	
	/**
	*  Calculates the speed of sound based on true airspeed and Mach number.
	*  Method:  a = VT/M
	*
	*  @param   inputs	Array of input parameters.
	*                   [0=true airspeed (VT), 1=Mach number (M)].
	*  @return  Speed of sound at altitude (a).
	**/
	public Parameter<Velocity> calc(Parameter[] inputs) {
		double VT = inputs[0].getValue();
		double M = inputs[1].doubleValue(Dimensionless.UNIT);
		
		double a = VT/M;
		
		return Parameter.valueOf(a, inputs[0].getUnit());
	}

}


