/*
*   afn_theta -- Calculates speed of sound as a function of theta.
*   
*   Copyright (C) 1998 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Velocity;
import javax.measure.quantity.Dimensionless;
import javax.measure.unit.SI;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates the speed of sound at altitude based on
*  temperature ratio.
*
*  <p>  Modified by:  Joseph A. Huwaldt    </p>
*
*  @author  Joseph A. Huwaldt  Date: October 13, 1998
*  @version July 24, 2011
**/
public class afn_theta extends AbstractParamMethod<Velocity> implements AtmosSharedData {
	
	/**
	*  Constructor for this method.
	*
	*  @param   theta  Label for the "temperature ratio" parameter.
	**/
	public afn_theta(String theta) {
		_inputLabels = new String[1];
		_inputLabels[0] = theta;
	}
	
	
	/**
	*  Calculates the speed of sound at altitude based on temperature ratio.
	*  Method:  a = a0*sqrt(theta)
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=temperature ratio (theta)].
	*  @return  Speed of sound at altitude (a).
	**/
	public Parameter<Velocity> calc(Parameter[] inputs) {
		Parameter theta = inputs[0];
		
		Parameter a = atmosModel.a0().times(theta.sqrt());			//	a = a0*sqrt(theta)
		
		return a;
	}

}
