/*
*   deltafn_P -- Calculates pressure ratio as a function of P.
*   
*   Copyright (C) 1998 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Dimensionless;
import javax.measure.quantity.Pressure;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates the pressure ratio based on air pressure
*  at altitude.
*
*  <p>  Modified by:  Joseph A. Huwaldt    </p>
*
*  @author   Joseph A. Huwaldt  Date: October 13, 1998
*  @version  July 24, 2011
**/
public class deltafn_P extends AbstractParamMethod<Dimensionless> implements AtmosSharedData {
	
	/**
	*  Constructor for this method.
	*
	*  @param   P  Label for the "static pressure" parameter.
	**/
	public deltafn_P(String P) {
		_inputLabels = new String[1];
		_inputLabels[0] = P;
	}
	
	
	/**
	*  Calculates the pressure ratio based on geometric altitude.
	*  Method:  delta = P/P0
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=air pressure at altitude (P)].
	*  @return  Pressure ratio (P/Po).
	**/
	public Parameter<Dimensionless> calc(Parameter[] inputs) {
		Parameter P = inputs[0];
		
		Parameter delta = P.divide(atmosModel.P0());
		
		return delta;
	}

}

