/*
*   rhofn_sigma -- Calculates static density as a function of sigma.
*   
*   Copyright (C) 1998 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.VolumetricDensity;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates the static air density based on density ratio.
*
*  <p>  Modified by:  Joseph A. Huwaldt    </p>
*
*  @author   Joseph A. Huwaldt  Date: October 12, 1998
*  @version  July 24, 2011
**/
public class rhofn_sigma extends AbstractParamMethod<VolumetricDensity> implements AtmosSharedData {
	
	/**
	*  Constructor for this method.
	*
	*  @param   sigma  Label for the "density ratio" parameter.
	**/
	public rhofn_sigma(String sigma) {
		_inputLabels = new String[1];
		_inputLabels[0] = sigma;
	}
	
	
	/**
	*  Calculates the static air density based on density ratio.
	*  Method:  rho = RHO0*sigma
	*
	*  @param   inputs	Array of input parameters.
	*                   [0=density ratio (sigma)].
	*  @return  Density (rho) in kg/L.
	**/
	public Parameter<VolumetricDensity> calc(Parameter[] inputs) {
		Parameter sigma = inputs[0];
		
		Parameter rho = atmosModel.RHO0().times(sigma);
		
		return rho;
	}

}

