/*
*   sigmafn_h -- Calculates density ratio as a function of h.
*   
*   Copyright (C) 1998 - 2006 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Dimensionless;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates the density ratio based on geometric altitude.
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date:  September 29, 1998
*  @version  July 24, 2011
**/
public class sigmafn_h extends AbstractParamMethod<Dimensionless> implements AtmosSharedData {
	
	/**
	*  Constructor for this method.
	*
	*  @param   h  Label for the "altitude" parameter.
	**/
	public sigmafn_h(String h) {
		_inputLabels = new String[1];
		_inputLabels[0] = h;
	}
	
	
	/**
	*  Calculates the density ratio based on geometric altitude.
	*  Method:  Density Ratio from 1976 standard atmosphere.
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=geometric altitude (h)].
	*  @return  Density ratio (rho/rho_o).
	**/
	public Parameter<Dimensionless> calc(Parameter[] inputs) {
		Parameter h = inputs[0];
		
		atmosModel.setAltitude(h);		//	Set altitude.
		
		Parameter sigma = atmosModel.getDensityRatio();
		
		return sigma;
	}

}
