/*
*   thetafn_T -- Calculates temperature ratio as a function of T.
*   
*   Copyright (C) 1998 - 2011 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2.1 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*  You should have received a copy of the GNU Lesser General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*  Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.js.pmethods.stdatmos;

import javax.measure.quantity.Dimensionless;
import javax.measure.quantity.Temperature;

import jahuwaldt.js.param.Parameter;
import jahuwaldt.js.ParamTools.*;


/**
*  Calculates the temperature ratio based on
*  temperature at altitude.
*
*  <p>  Modified by:  Joseph A. Huwaldt    </p>
*
*  @author  Joseph A. Huwaldt   Date: October 13, 1998
*  @version July 24, 2011
**/
public class thetafn_T extends AbstractParamMethod<Dimensionless> implements AtmosSharedData {
	
	/**
	*  Constructor for this method.
	*
	*  @param   T  Label for the "static temperature" parameter.
	**/
	public thetafn_T(String T) {
		_inputLabels = new String[1];
		_inputLabels[0] = T;
	}
	
	
	/**
	*  Calculates the temperature ratio based on temperature at altitude.
	*  Method:  theta = T/T0
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=temperature at altitude (T)].
	*  @return  Temperature ratio (T/To).
	**/
	public Parameter<Dimensionless> calc(Parameter[] inputs) {
		Parameter T = inputs[0];
		
		Parameter theta = T.divide(atmosModel.T0());
		
		return theta;
	}

}
